---
title: Model With Stacked And Unstacked Function Components
---

![Model With Stacked And Unstacked Function Components](../baseline/model_with_stacked_and_unstacked_function_components.png)

??? imports "Imports"
    ```python
    --8<--
    examples/model_ex/model_with_stacked_and_unstacked_function_components.py:imports
    --8<--
    ```

??? setup "Setup"
    ```python
    --8<--
    examples/model_ex/model_with_stacked_and_unstacked_function_components.py:setup
    --8<--
    ```

!!! tip "Code"
    ```python
    --8<--
    examples/model_ex/model_with_stacked_and_unstacked_function_components.py:plot_body
    --8<--
    ```

??? code "Full code"
    ```python
    --8<--
    examples/model_ex/model_with_stacked_and_unstacked_function_components.py:full_code
    --8<--
    ```
